@@ -19,7 +19,8 @@
 #ifndef GPARTED_LINUX_SWAP_H
 #define GPARTED_LINUX_SWAP_H
 
-#include "../include/FileSystem.h"
+#include "FileSystem.h"
+#include "Partition.h"
 
 namespace GParted
 {
@@ -36,7 +37,7 @@ public:
 	void read_uuid( Partition & partition ) ;
 	bool write_uuid( const Partition & partition, OperationDetail & operationdetail ) ;
 	bool create( const Partition & new_partition, OperationDetail & operationdetail ) ;
-	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition = false ) ;
+	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition );
 	bool move( const Partition & partition_new
 	         , const Partition & partition_old
 	         , OperationDetail & operationdetail
