@@ -14,8 +14,10 @@
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "../include/DMRaid.h"
+#include "DMRaid.h"
+#include "Partition.h"
 
+#include <limits.h>
 #include <stdlib.h>		//atoi function
 
 namespace GParted
@@ -125,11 +127,11 @@ bool DMRaid::is_dmraid_device( const Glib::ustring & dev_path )
 		if ( ! device_found && file_test( dev_path, Glib::FILE_TEST_IS_SYMLINK ) )
 		{
 			//Path is a symbolic link so find real path
-			char c_str[4096+1] ;
-			//FIXME: it seems realpath is very unsafe to use (manpage)...
-			if ( realpath( dev_path .c_str(), c_str ) != NULL )
+			char * rpath = realpath( dev_path.c_str(), NULL );
+			if ( rpath != NULL )
 			{
-				Glib::ustring tmp_path = c_str ;
+				Glib::ustring tmp_path = rpath;
+				free( rpath );
 				if ( tmp_path .length() > 0 )
 					for ( unsigned int k=0; k < dmraid_devices .size(); k++ )
 						if ( tmp_path .find( dmraid_devices[k] ) != Glib::ustring::npos )
@@ -166,7 +168,7 @@ void DMRaid::get_devices( std::vector<Glib::ustring> & device_list )
 	device_list .clear() ;
 
 	for ( unsigned int k=0; k < dmraid_devices .size(); k++ )
-		device_list .push_back( DEV_MAP_PATH + dmraid_devices[k] ) ;
+		device_list.push_back( DEV_MAPPER_PATH + dmraid_devices[k] );
 }
 
 Glib::ustring DMRaid::get_dmraid_name( const Glib::ustring & dev_path )
@@ -195,11 +197,11 @@ Glib::ustring DMRaid::get_dmraid_name( const Glib::ustring & dev_path )
 		if ( dmraid_name .empty() && file_test( dev_path, Glib::FILE_TEST_IS_SYMLINK ) )
 		{
 			//Path is a symbolic link so find real path
-			char c_str[4096+1] ;
-			//FIXME: it seems realpath is very unsafe to use (manpage)...
-			if( realpath( dev_path .c_str(), c_str ) != NULL )
+			char * rpath = realpath( dev_path.c_str(), NULL );
+			if ( rpath != NULL )
 			{
-				Glib::ustring tmp_path = c_str ;
+				Glib::ustring tmp_path = rpath;
+				free( rpath );
 				if ( tmp_path .length() > 0 )
 					for ( unsigned int k=0; k < dmraid_devices .size(); k++ )
 						if ( tmp_path .find( dmraid_devices[k] ) != Glib::ustring::npos )
@@ -219,7 +221,7 @@ void DMRaid::get_dmraid_dir_entries( const Glib::ustring & dev_path, std::vector
 
 	//Loop through the entries in the directory
 	Glib::ustring filename = "" ;
-	Glib::Dir dir( DEV_MAP_PATH) ;
+	Glib::Dir dir( DEV_MAPPER_PATH );
 	while ( ( filename = dir .read_name() ) != "" )
 	{
 		if ( filename == "control" )
@@ -286,11 +288,11 @@ Glib::ustring DMRaid::make_path_dmraid_compatible( Glib::ustring partition_path
 
 	for ( unsigned int k=0; k < dmraid_devices .size(); k++ )
 	{
-		reg_exp = DEV_MAP_PATH + dmraid_devices[ k ] + "p([0-9]+)" ;
+		reg_exp = DEV_MAPPER_PATH + dmraid_devices[k] + "p([0-9]+)";
 		partition_number = Utils::regexp_label( partition_path, reg_exp ) ;
 		if ( ! partition_number .empty() )
 		{
-			partition_path = DEV_MAP_PATH + dmraid_devices[ k ] + partition_number ;
+			partition_path = DEV_MAPPER_PATH + dmraid_devices[k] + partition_number;
 			return partition_path ;
 		}
 	}
@@ -307,7 +309,7 @@ Glib::ustring DMRaid::make_path_dmraid_compatible( Glib::ustring partition_path
 		if ( ! device_path .empty() )
 		{
 			device_path = get_udev_dm_name( device_path ) ;
-			partition_path = DEV_MAP_PATH + device_path + partition_number ;
+			partition_path = DEV_MAPPER_PATH + device_path + partition_number;
 		}
 	}
 
@@ -322,7 +324,7 @@ bool DMRaid::create_dev_map_entries( const Partition & partition, OperationDetai
 	bool exit_status = true ;
 
 	/*TO TRANSLATORS: looks like  create missing /dev/mapper entries */ 
-	Glib::ustring tmp = String::ucompose ( _("create missing %1 entries"), DEV_MAP_PATH ) ;
+	Glib::ustring tmp = String::ucompose ( _("create missing %1 entries"), DEV_MAPPER_PATH );
 	operationdetail .add_child( OperationDetail( tmp ) );
 
 	//Newer dmraid defaults to always inserting the letter 'p' between the device name
@@ -421,14 +423,14 @@ bool DMRaid::delete_affected_dev_map_entries( const Partition & partition, Opera
 	bool exit_status = true ;
 
 	/*TO TRANSLATORS: looks like  delete affected /dev/mapper entries */ 
-	Glib::ustring tmp = String::ucompose ( _("delete affected %1 entries"), DEV_MAP_PATH ) ;
+	Glib::ustring tmp = String::ucompose ( _("delete affected %1 entries"), DEV_MAPPER_PATH );
 	operationdetail .add_child( OperationDetail( tmp ) );
 
 	get_affected_dev_map_entries( partition, affected_entries ) ;
 
 	for ( unsigned int k=0; k < affected_entries .size(); k++ )
 	{
-		command = "dmsetup remove " + DEV_MAP_PATH + affected_entries[k] ;
+		command = "dmsetup remove " + DEV_MAPPER_PATH + affected_entries[k];
 		if ( execute_command( command, operationdetail .get_last_child() ) )
 			exit_status = false ;	//command failed
 	}
@@ -444,7 +446,7 @@ bool DMRaid::delete_dev_map_entry( const Partition & partition, OperationDetail
 	bool exit_status = true ;
 
 	/*TO TRANSLATORS: looks like  delete /dev/mapper entry */ 
-	Glib::ustring tmp = String::ucompose ( _("delete %1 entry"), DEV_MAP_PATH ) ;
+	Glib::ustring tmp = String::ucompose ( _("delete %1 entry"), DEV_MAPPER_PATH );
 	operationdetail .add_child( OperationDetail( tmp ) );
 
 	std::vector<Glib::ustring> partition_entries ;
@@ -475,7 +477,7 @@ bool DMRaid::purge_dev_map_entries( const Glib::ustring & dev_path )
 
 	for ( unsigned int k=0; k < dir_list .size(); k++ )
 	{
-		command = "dmsetup remove " + DEV_MAP_PATH + dir_list[k] ;
+		command = "dmsetup remove " + DEV_MAPPER_PATH + dir_list[k];
 		if ( Utils::execute_command( command, output, error, true ) )
 			exit_status = false ;	//command failed
 	}
@@ -494,7 +496,7 @@ bool DMRaid::update_dev_map_entry( const Partition & partition, OperationDetail
 	bool exit_status = true ;
 
 	/*TO TRANSLATORS: looks like  update /dev/mapper entry */ 
-	Glib::ustring tmp = String::ucompose ( _("update %1 entry"), DEV_MAP_PATH ) ;
+	Glib::ustring tmp = String::ucompose ( _("update %1 entry"), DEV_MAPPER_PATH );
 	operationdetail .add_child( OperationDetail( tmp ) );
 
 	if( ! delete_dev_map_entry( partition , operationdetail .get_last_child() ) )
