@@ -15,19 +15,22 @@
  */
 
 
-#include "../include/OperationDetail.h"
-#include "../include/Utils.h"
+#include "OperationDetail.h"
+#include "ProgressBar.h"
+#include "Utils.h"
 
 namespace GParted
 {
 
-OperationDetail::OperationDetail() : fraction( -1 ), cancelflag( 0 ), status( STATUS_NONE ), time_start( -1 ),
-				     time_elapsed( -1 )
+// The single progress bar for the current operation
+static ProgressBar single_progressbar;
+
+OperationDetail::OperationDetail() : cancelflag( 0 ), status( STATUS_NONE ), time_start( -1 ), time_elapsed( -1 )
 {
 }
 
 OperationDetail::OperationDetail( const Glib::ustring & description, OperationDetailStatus status, Font font ) :
-	fraction( -1 ), cancelflag( 0 ), status( STATUS_NONE ), time_start( -1 ), time_elapsed( -1 )
+	cancelflag( 0 ), status( STATUS_NONE ), time_start( -1 ), time_elapsed( -1 )
 {
 	set_description( description, font );
 	set_status( status );
@@ -156,6 +159,25 @@ OperationDetail & OperationDetail::get_last_child()
 	return *sub_details[sub_details.size() - 1];
 }
 
+void OperationDetail::run_progressbar( double progress, double target, ProgressBar_Text text_mode )
+{
+	if ( ! single_progressbar.running() )
+		single_progressbar.start( target, text_mode );
+	single_progressbar.update( progress );
+	signal_update.emit( *this );
+}
+
+void OperationDetail::stop_progressbar()
+{
+	if ( single_progressbar.running() )
+	{
+		single_progressbar.stop();
+		signal_update.emit( *this );
+	}
+}
+
+// Private methods
+
 void OperationDetail::on_update( const OperationDetail & operationdetail ) 
 {
 	if ( ! treepath .empty() )
@@ -168,7 +190,12 @@ void OperationDetail::cancel( bool force )
 		cancelflag = 2;
 	else
 		cancelflag = 1;
-	signal_cancel(force);
+	signal_cancel.emit( force );
+}
+
+ProgressBar & OperationDetail::get_progressbar() const
+{
+	return single_progressbar;
 }
 
 } //GParted
