@@ -102,7 +102,7 @@ Glib::ustring Utils::get_color( FILESYSTEM filesystem )
 		case FS_F2FS		: return "#DF421E" ;	//accent red
 		case FS_FAT16		: return "#00FF00" ;	//green
 		case FS_FAT32		: return "#18D918" ;	// ~ medium green
-		case FS_EXFAT		: return "#2E8B57" ;	// ~ sea green
+		case FS_EXFAT		: return "#267726" ;	// Accent Green Dark
 		case FS_NILFS2		: return "#826647" ;	//face skin shadow
 		case FS_NTFS		: return "#42E5AC" ;	// ~ light aquamarine
 		case FS_REISERFS	: return "#ADA7C8" ;	//purple hilight
@@ -111,6 +111,7 @@ Glib::ustring Utils::get_color( FILESYSTEM filesystem )
 		case FS_JFS			: return "#E0C39E" ;	//face skin medium
 		case FS_HFS			: return "#E0B6AF" ;	//red hilight
 		case FS_HFSPLUS		: return "#C0A39E" ;	// ~ serene red
+		case FS_UDF		: return "#105210";	// Accent Green Shadow
 		case FS_UFS			: return "#D1940C" ;	//accent yellow dark
 		case FS_USED		: return "#F8F8BA" ;	// ~ light tan yellow
 		case FS_UNUSED		: return "#FFFFFF" ;	//white
@@ -232,6 +233,7 @@ int Utils::get_filesystem_label_maxlength( FILESYSTEM filesystem )
 		case FS_NTFS		: return 128 ;
 		case FS_REISER4		: return 16 ;
 		case FS_REISERFS	: return 16 ;
+		case FS_UDF		: return 126;  // and only 63 if label contains character above U+FF
 		//case FS_UFS		: return  ;
 		case FS_XFS		: return 12 ;
 
@@ -289,6 +291,7 @@ Glib::ustring Utils::get_filesystem_string( FILESYSTEM filesystem )
 		case FS_JFS		: return "jfs" ;
 		case FS_HFS		: return "hfs" ;
 		case FS_HFSPLUS		: return "hfs+" ;
+		case FS_UDF		: return "udf";
 		case FS_UFS		: return "ufs" ;
 		case FS_USED		: return _("used") ;
 		case FS_UNUSED		: return _("unused") ;
@@ -337,6 +340,7 @@ const Glib::ustring Utils::get_filesystem_kernel_name( FILESYSTEM fstype )
 		case FS_NTFS     : return "ntfs";
 		case FS_REISER4  : return "reiser4";
 		case FS_REISERFS : return "reiserfs";
+		case FS_UDF      : return "udf";
 		case FS_UFS      : return "ufs";
 		case FS_XFS      : return "xfs";
 		default          : return "";
@@ -364,6 +368,7 @@ Glib::ustring Utils::get_filesystem_software( FILESYSTEM filesystem )
 		case FS_NTFS        : return "ntfs-3g / ntfsprogs" ;
 		case FS_REISER4     : return "reiser4progs" ;
 		case FS_REISERFS    : return "reiserfsprogs / reiserfs-utils" ;
+		case FS_UDF         : return "udftools";
 		case FS_UFS         : return "" ;
 		case FS_XFS         : return "xfsprogs, xfsdump" ;
 
@@ -601,8 +606,6 @@ int Utils::execute_command( const Glib::ustring & command,
 	fcntl( out, F_SETFL, O_NONBLOCK );
 	fcntl( err, F_SETFL, O_NONBLOCK );
 	g_child_watch_add( pid, _store_exit_status, &status );
-	output.clear();
-	error.clear();
 	//Lock mutex so we have time to setup pipecapture for output and error streams
 	//  before connecting the input/output signal handler
 	if( !status.foreground )
