@@ -111,7 +111,7 @@ FS btrfs::get_filesystem_support()
 	if ( ! Glib::find_program_in_path( "btrfstune" ).empty() )
 	{
 		Utils::execute_command( "btrfstune --help", output, error, true );
-		if ( Utils::regexp_label( error, "^[[:blank:]]*(-u)[[:blank:]]" ) == "-u" )
+		if ( Utils::regexp_label( output + error, "^[[:blank:]]*(-u)[[:blank:]]" ) == "-u" )
 			fs.write_uuid = FS::EXTERNAL;
 	}
 
@@ -320,7 +320,7 @@ bool btrfs::resize( const Partition & partition_new, OperationDetail & operation
 		mount_point = mk_temp_dir( "", operationdetail ) ;
 		if ( mount_point .empty() )
 			return false ;
-		success &= ! execute_command( "mount -v -t btrfs " + path + " " + mount_point,
+		success &= ! execute_command( "mount -v -t btrfs " + path + " \"" + mount_point + "\"",
 		                              operationdetail, EXEC_CHECK_STATUS );
 	}
 	else
@@ -336,9 +336,9 @@ bool btrfs::resize( const Partition & partition_new, OperationDetail & operation
 			size = "max" ;
 		Glib::ustring cmd ;
 		if ( btrfs_found )
-			cmd = "btrfs filesystem resize " + devid_str + ":" + size + " " + mount_point ;
+			cmd = "btrfs filesystem resize " + devid_str + ":" + size + " \"" + mount_point + "\"";
 		else
-			cmd = "btrfsctl -r " + devid_str + ":" + size + " " + mount_point ;
+			cmd = "btrfsctl -r " + devid_str + ":" + size + " \"" + mount_point + "\"";
 		exit_status = execute_command( cmd, operationdetail );
 		bool resize_succeeded = ( exit_status == 0 ) ;
 		if ( resize_to_same_size_fails )
@@ -365,8 +365,8 @@ bool btrfs::resize( const Partition & partition_new, OperationDetail & operation
 		success &= resize_succeeded ;
 
 		if ( ! partition_new .busy )
-			success &= ! execute_command( "umount -v " + mount_point, operationdetail,
-			                              EXEC_CHECK_STATUS );
+			success &= ! execute_command( "umount -v \"" + mount_point + "\"",
+			                              operationdetail, EXEC_CHECK_STATUS );
 	}
 
 	if ( ! partition_new .busy )
