@@ -14,11 +14,10 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
- 
-#include "../include/linux_swap.h"
-#include "../include/BlockSpecial.h"
-#include "../include/Partition.h"
+
+#include "linux_swap.h"
+#include "BlockSpecial.h"
+#include "Partition.h"
 
 #include <cerrno>
 
@@ -55,6 +54,8 @@ FS linux_swap::get_filesystem_support()
 		fs .create_with_label = GParted::FS::EXTERNAL ;
 		fs .grow = GParted::FS::EXTERNAL ;
 		fs .shrink = GParted::FS::EXTERNAL ;
+		fs.copy = FS::EXTERNAL;
+		fs.move = FS::EXTERNAL;
 	}
 
 	if ( ! Glib::find_program_in_path( "swaplabel" ) .empty() )
@@ -65,9 +66,6 @@ FS linux_swap::get_filesystem_support()
 		fs .write_uuid = FS::EXTERNAL ;
 	}
 
-	fs .copy = GParted::FS::EXTERNAL ;
-	fs .move = GParted::FS::EXTERNAL ;
-	
 	return fs ;
 }
 
@@ -169,19 +167,12 @@ bool linux_swap::create( const Partition & new_partition, OperationDetail & oper
 
 bool linux_swap::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
-	/*TO TRANSLATORS: looks like create new linux-swap file system */ 
-	operationdetail .add_child( OperationDetail( 
-		String::ucompose( _("create new %1 file system"), Utils::get_filesystem_string( FS_LINUX_SWAP ) ) ) ) ;
-
 	//Maintain label and uuid when recreating swap
 	Glib::ustring command = "mkswap -L \"" + partition_new.get_filesystem_label() + "\" ";
 	if ( ! partition_new .uuid .empty() )
 		command +=  " -U \"" + partition_new .uuid + "\" " ;
 	command += partition_new .get_path() ;
-	bool exit_status = ! execute_command( command , operationdetail.get_last_child(), EXEC_CHECK_STATUS );
-
-	operationdetail .get_last_child() .set_status( exit_status ? STATUS_SUCCES : STATUS_ERROR ) ;
-	return exit_status ;
+	return ! execute_command( command, operationdetail, EXEC_CHECK_STATUS );
 }
 
 bool linux_swap::move( const Partition & partition_new
